import { defineComponent, toRef, reactive, watch, openBlock, createElementBlock, Fragment, renderList, createCommentVNode, createElementVNode, pushScopeId, popScopeId } from 'vue';

const _withScopeId = n => (pushScopeId("data-v-52cb2ce0"), n = n(), popScopeId(), n);
const _hoisted_1 = { class: "ip_input_container" };
const _hoisted_2 = { class: "ip_input_box" };
const _hoisted_3 = ["name", "value", "onInput"];
const _hoisted_4 = {
    key: 0,
    class: "symbol_box"
};
const _hoisted_5 = {
    key: 0,
    class: "ip_input_box"
};
const _hoisted_6 = /*#__PURE__*/ _withScopeId(() => /*#__PURE__*/ createElementVNode("i", null, ":", -1 /* HOISTED */));
const _hoisted_7 = ["value"];
var script = /*#__PURE__*/ defineComponent({
    __name: 'IpInput',
    props: {
        ip: {
            type: String,
        },
        port: {
            type: Number,
        },
    },
    emits: ["update:port", "update:ip", "change"],
    setup(__props, { emit }) {
        const props = __props;
        const portRef = toRef(props, "port");
        const inputRefs = [];
        const state = reactive({
            ipControlArr: new Array(4),
            ipArrs: new Array(4),
        });
        /**
         * @description: 获取input框的ref
         * @param {*} el
         * @return {*}
         */
        const setInputRef = (el) => {
            if (!el || inputRefs.findIndex((inputRef) => inputRef.name === el.name) > -1)
                return;
            inputRefs.push(el);
        };
        /**
         * @description: 根据输入的数据设置新的值
         * @return {*}
         */
        const handleInput = (index, el) => {
            const targetValue = el.target.value;
            // 将原始值设置到输入框中
            el.target.value = state.ipControlArr[index] ?? "";
            // 输入. 跳转下个
            if (el.data === "." && index < state.ipControlArr.length - 1) {
                inputRefs[index + 1].focus();
                if (state.ipControlArr[index + 1] !== "") {
                    inputRefs[index + 1].select();
                }
                return;
            }
            // 如果输入的不是一个数字
            if (isNaN(Number(el.data))) {
                return;
            }
            if (Number(targetValue) < 0) {
                state.ipControlArr[index] = 0;
            }
            else if (Number(targetValue) > 255) {
                state.ipControlArr[index] = 255;
            }
            else {
                // 设置新的值
                state.ipControlArr[index] = targetValue;
            }
            const ip = state.ipControlArr.join(".");
            // 返回新的值
            emit("update:ip", ip);
            // 调用返回值
            emit("change", ip, props.port);
            // 当前的值时三位数没到最后时，下一个自动获取焦点
            if (targetValue.length === 3 && index < state.ipControlArr.length - 1) {
                inputRefs[index + 1].focus();
                if (state.ipControlArr[index + 1] !== "") {
                    inputRefs[index + 1].select();
                }
            }
        };
        /**
         * @description: 展示端口，端口数据更新
         * @param {*} e
         * @return {*}
         */
        const handleInputPort = (e) => {
            if (e.target.value) {
                // 触发了
                emit("update:port", Number(e.target.value));
                emit("change", state.ipControlArr.join("."), Number(e.target.value));
            }
        };
        watch(() => props.ip, (ip) => {
            ip?.split(".")?.forEach((el, index) => {
                state.ipControlArr[index] = el ? Number(el) : "";
            });
        }, {
            immediate: true,
        });
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", _hoisted_1, [
                (openBlock(true), createElementBlock(Fragment, null, renderList(state.ipControlArr, (item, index) => {
                    return (openBlock(), createElementBlock("div", _hoisted_2, [
                        (openBlock(), createElementBlock("input", {
                            ref_for: true,
                            ref: setInputRef,
                            key: index,
                            name: index + '',
                            value: item,
                            type: "text",
                            onInput: (el) => handleInput(index, el)
                        }, null, 40 /* PROPS, HYDRATE_EVENTS */, _hoisted_3)),
                        (index < state.ipControlArr.length - 1)
                            ? (openBlock(), createElementBlock("i", _hoisted_4, "·"))
                            : createCommentVNode("v-if", true)
                    ]));
                }), 256 /* UNKEYED_FRAGMENT */)),
                (__props.port !== undefined)
                    ? (openBlock(), createElementBlock("div", _hoisted_5, [
                        _hoisted_6,
                        createElementVNode("input", {
                            class: "port_input",
                            value: portRef.value,
                            onInput: handleInputPort,
                            type: "number"
                        }, null, 40 /* PROPS, HYDRATE_EVENTS */, _hoisted_7)
                    ]))
                    : createCommentVNode("v-if", true)
            ]));
        };
    }
});

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = "\n.ip_input_container[data-v-52cb2ce0] {\r\n  display: inline-flex;\r\n  align-items: center;\r\n  border: 1px solid #ccc;\r\n  box-sizing: border-box;\r\n  min-height: 32px;\n}\n.ip_input_container[data-v-52cb2ce0]:hover {\r\n  border-color: #40a9ff;\n}\n.ip_input_box[data-v-52cb2ce0] {\r\n  display: inline-flex;\r\n  align-items: center;\n}\ninput[data-v-52cb2ce0] {\r\n  outline: none;\r\n  width: 40px;\r\n  border: none;\r\n  text-align: center;\r\n  line-height: 1px;\n}\ninput[type=\"number\"][data-v-52cb2ce0]::-webkit-inner-spin-button,\r\ninput[type=\"number\"][data-v-52cb2ce0]::-webkit-outer-spin-button {\r\n  -webkit-appearance: none;\r\n  margin: 0;\n}\n.symbol_box[data-v-52cb2ce0] {\r\n  font-weight: 500;\n}\n.port_input[data-v-52cb2ce0] {\r\n  width: 60px;\r\n  margin: 0 8px;\n}\r\n";
styleInject(css_248z);

script.__scopeId = "data-v-52cb2ce0";
script.__file = "package/IpInput/IpInput.vue";

script.install = (app) => {
    app.component("IpInput", script);
};
const IpInputVue = script;

export { IpInputVue as default };
